@@ -5,7 +5,7 @@ use File::Spec;
 use Getopt::Long qw/GetOptionsFromArray/;
 use IO::Interactive::Tiny;
 
-our $VERSION = '0.09';
+our $VERSION = '0.091';
 
 our $DEFAULT_RCFILE_NAME = '.statsrc';
 
@@ -86,7 +86,7 @@ sub _read_rc {
 sub _parse_rc {
     my ($self, $file, $config) = @_;
 
-    open my $fh, '<', $file or die "Could not open file: $file";
+    open my $fh, '<', $file;
     while (<$fh>) {
         chomp;
         next if /\A\s*\Z/sm;
@@ -330,7 +330,7 @@ sub _finalize {
 
     my $lf = $self->config->{cr} ? "\r" : $self->config->{crlf} ? "\r\n" : "\n";
 
-    print $lf unless $self->config->{quiet};
+    print $lf;
     for my $line ( @{$output_lines} ) {
         print $line, $lf;
     }
